from setuptools import setup, find_packages


def readme():
    with open('README.md', 'r') as f:
        return f.read()


setup(
    name='lexi_craft',
    version='0.1',
    author='PurpleFta',
    author_email='helloworldfirstfta@gmail.com',
    description='Корректирует текст согласно грамматическим нормам',
    long_description=readme(),
    long_description_content_type='text/markdown',
    url='https://github.com/purple-fta/lexi_craft',
    packages=find_packages(),
    install_requires=["python-dotenv", "openai"],
    classifiers=[
        'Programming Language :: Python :: 3.11',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ],
    keywords='text correction grammar',
    project_urls={
        'GitHub': 'https://github.com/purple-fta/lexi_craft'
    },
    python_requires='>=3.6'
)




import openai
import os


#  TODO: Docs
#  TODO: Type checking


BASE_PROMPT = "\nПерепиши этот текст на русском языке со всеми грамматическими нормами русского языка. Избавься от лишних сслов паразитов, для этого можешь слегка перефразировать текст. Но не использую восклицательный знак."


def init(api_key: str | None = None) -> None:
    if api_key is None:
        api_key = os.getenv("OPENAI_API_KEY")

        if api_key is None:
            from dotenv import load_dotenv

            load_dotenv()

            api_key = os.getenv("OPENAI_API_KEY")
            
            if api_key is None:
                print("Please set your OpenAI API key as an environment variable or pass it as a parameter to the init function.")
                exit(1)

    openai.api_key = api_key
    

def decorate_text(text: str) -> str | None:
    prompt = f'"{text}"' + BASE_PROMPT

    response = openai.chat.completions.create(
        model="gpt-3.5-turbo",
        messages=[
            {"role": "user", "content": prompt}
        ]
    )
    
    return response.choices[0].message.content

